 /* SPDX-License-Identifier: GPL-2.0 */

/***************************************************************************
 *    copyright		   : (C) 2002 by Frank Mori Hess
 ***************************************************************************/

#ifndef _GPIB_USER_H
#define _GPIB_USER_H

#include <linux/types.h>
#include "gpib.h"


/* IBERR error codes */
enum iberr_code {
	EDVR = 0,		/* system error */
	ECIC = 1,		/* not CIC */
	ENOL = 2,		/* no listeners */
	EADR = 3,		/* CIC and not addressed before I/O */
	EARG = 4,		/* bad argument to function call */
	ESAC = 5,		/* not SAC */
	EABO = 6,		/* I/O operation was aborted */
	ENEB = 7,		/* non-existent board (GPIB interface offline) */
	EDMA = 8,		/* DMA hardware error detected */
	EOIP = 10,		/* new I/O attempted with old I/O in progress  */
	ECAP = 11,		/* no capability for intended opeation */
	EFSO = 12,		/* file system operation error */
	EBUS = 14,		/* bus error */
	ESTB = 15,		/* lost serial poll bytes */
	ESRQ = 16,		/* SRQ stuck on */
	ECNF = 17,              /* Configuration file error */
	ETAB = 20	       /* Table Overflow */
};

/* Timeout values and meanings */
enum gpib_timeout {
	TNONE = 0,		/* Infinite timeout (disabled)	   */
	T10us = 1,		/* Timeout of 10 usec (ideal)	   */
	T30us = 2,		/* Timeout of 30 usec (ideal)	   */
	T100us = 3,		/* Timeout of 100 usec (ideal)	   */
	T300us = 4,		/* Timeout of 300 usec (ideal)	   */
	T1ms = 5,		/* Timeout of 1 msec (ideal)	   */
	T3ms = 6,		/* Timeout of 3 msec (ideal)	   */
	T10ms = 7,		/* Timeout of 10 msec (ideal)	   */
	T30ms = 8,		/* Timeout of 30 msec (ideal)	   */
	T100ms = 9,		/* Timeout of 100 msec (ideal)	   */
	T300ms = 10,	/* Timeout of 300 msec (ideal)	   */
	T1s = 11,		/* Timeout of 1 sec (ideal)	   */
	T3s = 12,		/* Timeout of 3 sec (ideal)	   */
	T10s = 13,		/* Timeout of 10 sec (ideal)	   */
	T30s = 14,		/* Timeout of 30 sec (ideal)	   */
	T100s = 15,		/* Timeout of 100 sec (ideal)	   */
	T300s = 16,		/* Timeout of 300 sec (ideal)	   */
	T1000s = 17		/* Timeout of 1000 sec (maximum)   */
};

static const int gpib_addr_max = 30;	/* max address for primary/secondary gpib addresses */
static const int gpib_sad_max = 31;	/* (0x1f) max address for secondary gpib addresses */


static __inline__ uint8_t CFGn( unsigned int meters )
{
	return 0x6 | (meters & 0xf);
}

/*  Compatibility defines due to removal of CamelCase identifiers in kernel code */

/* GPIB Bus Control Lines bit vector */
#define ValidDAV  VALID_DAV
#define ValidNDAC VALID_NDAC
#define ValidNRFD VALID_NRFD
#define ValidIFC  VALID_IFC
#define ValidREN  VALID_REN
#define ValidSRQ  VALID_SRQ
#define ValidATN  VALID_ATN
#define ValidEOI  VALID_EOI
#define ValidALL  VALID_ALL
#define BusDAV    BUS_DAV
#define BusNDAC   BUS_NDAC
#define BusNRFD   BUS_NRFD
#define BusIFC    BUS_IFC
#define BusREN    BUS_REN
#define BusSRQ    BUS_SRQ
#define BusATN    BUS_ATN
#define BusEOI    BUS_EOI

#define PPConfig PP_CONFIG

/* ibask options */
#define	IbaPAD            IBA_PAD
#define	IbaSAD		  IBA_SAD
#define	IbaTMO		  IBA_TMO
#define	IbaEOT		  IBA_EOT
#define	IbaPPC		  IBA_PPC
#define	IbaREADDR	  IBA_READ_DR
#define	IbaAUTOPOLL	  IBA_AUTOPOLL
#define	IbaCICPROT	  IBA_CICPROT
#define	IbaIRQ		  IBA_IRQ
#define	IbaSC		  IBA_SC
#define	IbaSRE		  IBA_SRE
#define	IbaEOSrd	  IBA_EOS_RD
#define	IbaEOSwrt	  IBA_EOS_WRT
#define	IbaEOScmp	  IBA_EOS_CMP
#define	IbaEOSchar	  IBA_EOS_CHAR
#define	IbaPP2		  IBA_PP2
#define	IbaTIMING	  IBA_TIMING
#define	IbaDMA		  IBA_DMA
#define	IbaReadAdjust	  IBA_READ_ADJUST
#define	IbaWriteAdjust	  IBA_WRITE_ADJUST
#define	IbaEventQueue	  IBA_EVENT_QUEUE
#define	IbaSPollBit	  IBA_SPOLL_BIT
#define	IbaSpollBit	  IBA_SPOLL_BIT
#define	IbaSendLLO	  IBA_SEND_LLO
#define	IbaSPollTime	  IBA_SPOLL_TIME
#define	IbaPPollTime	  IBA_PPOLL_TIME
#define	IbaEndBitIsNormal IBA_END_BIT_IS_NORMAL
#define	IbaUnAddr	  IBA_UN_ADDR
#define	IbaHSCableLength  IBA_HS_CABLE_LENGTH
#define	IbaIst		  IBA_IST
#define	IbaRsv		  IBA_RSV
#define	IbaBNA		  IBA_BNA
#define Iba7BitEOS        IBA_7_BIT_EOS
/* ibconfig options */
#define	IbcPAD            IBC_PAD
#define	IbcSAD		  IBC_SAD
#define	IbcTMO		  IBC_TMO
#define	IbcEOT		  IBC_EOT
#define	IbcPPC		  IBC_PPC
#define	IbcREADDR	  IBC_READDR
#define	IbcAUTOPOLL	  IBC_AUTOPOLL
#define	IbcCICPROT	  IBC_CICPROT
#define	IbcIRQ		  IBC_IRQ
#define	IbcSC		  IBC_SC
#define	IbcSRE		  IBC_SRE
#define	IbcEOSrd	  IBC_EOS_RD
#define	IbcEOSwrt	  IBC_EOS_WRT
#define	IbcEOScmp	  IBC_EOS_CMP
#define	IbcEOSchar	  IBC_EOS_CHAR
#define	IbcPP2		  IBC_PP2
#define	IbcTIMING	  IBC_TIMING
#define	IbcDMA		  IBC_DMA
#define	IbcReadAdjust	  IBC_READ_ADJUST
#define	IbcWriteAdjust	  IBC_WRITE_ADJUST
#define	IbcEventQueue	  IBC_EVENT_QUEUE
#define	IbcSPollBit	  IBC_SPOLL_BIT
#define	IbcSpollBit	  IBC_SPOLL_BIT
#define	IbcSendLLO	  IBC_SEND_LLO
#define	IbcSPollTime	  IBC_SPOLL_TIME
#define	IbcPPollTime	  IBC_PPOLL_TIME
#define	IbcEndBitIsNormal IBC_END_BIT_IS_NORMAL
#define	IbcUnAddr	  IBC_UN_ADDR
#define	IbcHSCableLength  IBC_HS_CABLE_LENGTH
#define	IbcIst		  IBC_IST
#define	IbcRsv		  IBC_RSV
#define	IbcBNA		  IBC_BNA

/* gpib events */
#define	EventNone   EVENT_NONE
#define	EventDevTrg EVENT_DEV_TRG
#define	EventDevClr EVENT_DEV_CLR
#define	EventIFC    EVENT_IFC

/* standard status byte bits */
#define	IbStbRQS IB_STB_RQS
#define	IbStbESB IB_STB_ESB
#define	IbStbMAV IB_STB_MAV


#endif	/* _GPIB_USER_H */
